"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgSubmitProposal(google.protobuf.message.Message):
    """MsgSubmitProposal defines an sdk.Msg type that supports submitting arbitrary
    proposal Content.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    INITIAL_DEPOSIT_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def initial_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    proposer: typing.Text
    def __init__(self,
        *,
        content: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        initial_deposit: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        proposer: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","initial_deposit",b"initial_deposit","proposer",b"proposer"]) -> None: ...
global___MsgSubmitProposal = MsgSubmitProposal

class MsgSubmitProposalResponse(google.protobuf.message.Message):
    """MsgSubmitProposalResponse defines the Msg/SubmitProposal response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id",b"proposal_id"]) -> None: ...
global___MsgSubmitProposalResponse = MsgSubmitProposalResponse

class MsgVote(google.protobuf.message.Message):
    """MsgVote defines a message to cast a vote."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: typing.Text
    option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        voter: typing.Text = ...,
        option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option",b"option","proposal_id",b"proposal_id","voter",b"voter"]) -> None: ...
global___MsgVote = MsgVote

class MsgVoteResponse(google.protobuf.message.Message):
    """MsgVoteResponse defines the Msg/Vote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgVoteResponse = MsgVoteResponse

class MsgVoteWeighted(google.protobuf.message.Message):
    """MsgVoteWeighted defines a message to cast a vote.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: typing.Text
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption]: ...
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        voter: typing.Text = ...,
        options: typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["options",b"options","proposal_id",b"proposal_id","voter",b"voter"]) -> None: ...
global___MsgVoteWeighted = MsgVoteWeighted

class MsgVoteWeightedResponse(google.protobuf.message.Message):
    """MsgVoteWeightedResponse defines the Msg/VoteWeighted response type.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgVoteWeightedResponse = MsgVoteWeightedResponse

class MsgDeposit(google.protobuf.message.Message):
    """MsgDeposit defines a message to submit a deposit to an existing proposal."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    depositor: typing.Text
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        depositor: typing.Text = ...,
        amount: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount","depositor",b"depositor","proposal_id",b"proposal_id"]) -> None: ...
global___MsgDeposit = MsgDeposit

class MsgDepositResponse(google.protobuf.message.Message):
    """MsgDepositResponse defines the Msg/Deposit response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgDepositResponse = MsgDepositResponse
