# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dex/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from dex.v1 import params_pb2 as dex_dot_v1_dot_params__pb2
from dex.v1 import pool_pb2 as dex_dot_v1_dot_pool__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x65x/v1/query.proto\x12\rnibiru.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x13\x64\x65x/v1/params.proto\x1a\x11\x64\x65x/v1/pool.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x14\n\x12QueryParamsRequest\"B\n\x13QueryParamsResponse\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x15.nibiru.dex.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x18\n\x16QueryPoolNumberRequest\")\n\x17QueryPoolNumberResponse\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"\"\n\x10QueryPoolRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"6\n\x11QueryPoolResponse\x12!\n\x04pool\x18\x01 \x01(\x0b\x32\x13.nibiru.dex.v1.Pool\"O\n\x11QueryPoolsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"u\n\x12QueryPoolsResponse\x12\"\n\x05pools\x18\x01 \x03(\x0b\x32\x13.nibiru.dex.v1.Pool\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"(\n\x16QueryPoolParamsRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"H\n\x17QueryPoolParamsResponse\x12-\n\npoolParams\x18\x01 \x01(\x0b\x32\x19.nibiru.dex.v1.PoolParams\"\x16\n\x14QueryNumPoolsRequest\")\n\x15QueryNumPoolsResponse\x12\x10\n\x08numPools\x18\x01 \x01(\x04\"\x1c\n\x1aQueryTotalLiquidityRequest\"\x91\x01\n\x1bQueryTotalLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\"0\n\x1eQueryTotalPoolLiquidityRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"\x95\x01\n\x1fQueryTotalPoolLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\")\n\x17QueryTotalSharesRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"g\n\x18QueryTotalSharesResponse\x12K\n\x0btotalShares\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\"T\n\x15QuerySpotPriceRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x14\n\x0ctokenInDenom\x18\x02 \x01(\t\x12\x15\n\rtokenOutDenom\x18\x03 \x01(\t\"+\n\x16QuerySpotPriceResponse\x12\x11\n\tspotPrice\x18\x01 \x01(\t\"\x8b\x01\n\x1dQuerySwapExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x43\n\x07tokenIn\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12\x15\n\rtokenOutDenom\x18\x03 \x01(\t\"g\n\x1eQuerySwapExactAmountInResponse\x12\x45\n\x08tokenOut\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\x8d\x01\n\x1eQuerySwapExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x45\n\x08tokenOut\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\x12\x14\n\x0ctokenInDenom\x18\x03 \x01(\t\"f\n\x1fQuerySwapExactAmountOutResponse\x12\x43\n\x07tokenIn\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\"\xa2\x01\n\x1dQueryJoinExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12q\n\x08tokensIn\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"tokens_in\"\xc8\xde\x1f\x00\"\xf4\x01\n\x1eQueryJoinExactAmountInResponse\x12_\n\rpoolSharesOut\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"pool_shares_out\"\xc8\xde\x1f\x00\x12q\n\x08remCoins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"rem_coins\"\xc8\xde\x1f\x00\"0\n\x1eQueryJoinExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"!\n\x1fQueryJoinExactAmountOutResponse\"\x8e\x01\n\x1dQueryExitExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12]\n\x0cpoolSharesIn\x18\x02 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x15yaml:\"pool_shares_in\"\xc8\xde\x1f\x00\"\x95\x01\n\x1eQueryExitExactAmountInResponse\x12s\n\ttokensOut\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\"0\n\x1eQueryExitExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"!\n\x1fQueryExitExactAmountOutResponse2\xeb\x12\n\x05Query\x12k\n\x06Params\x12!.nibiru.dex.v1.QueryParamsRequest\x1a\".nibiru.dex.v1.QueryParamsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/nibiru/dex/params\x12|\n\nPoolNumber\x12%.nibiru.dex.v1.QueryPoolNumberRequest\x1a&.nibiru.dex.v1.QueryPoolNumberResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/nibiru/dex/pool_number\x12\x63\n\x04Pool\x12\x1f.nibiru.dex.v1.QueryPoolRequest\x1a .nibiru.dex.v1.QueryPoolResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/nibiru/dex/pool\x12g\n\x05Pools\x12 .nibiru.dex.v1.QueryPoolsRequest\x1a!.nibiru.dex.v1.QueryPoolsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/nibiru/dex/pools\x12\x86\x01\n\nPoolParams\x12%.nibiru.dex.v1.QueryPoolParamsRequest\x1a&.nibiru.dex.v1.QueryPoolParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/dex/pools/{poolId}/params\x12t\n\x08NumPools\x12#.nibiru.dex.v1.QueryNumPoolsRequest\x1a$.nibiru.dex.v1.QueryNumPoolsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/nibiru/dex/num_pools\x12\x8c\x01\n\x0eTotalLiquidity\x12).nibiru.dex.v1.QueryTotalLiquidityRequest\x1a*.nibiru.dex.v1.QueryTotalLiquidityResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/nibiru/dex/total_liquidity\x12\xac\x01\n\x12TotalPoolLiquidity\x12-.nibiru.dex.v1.QueryTotalPoolLiquidityRequest\x1a..nibiru.dex.v1.QueryTotalPoolLiquidityResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//nibiru/dex/pools/{poolId}/total_pool_liquidity\x12\x8f\x01\n\x0bTotalShares\x12&.nibiru.dex.v1.QueryTotalSharesRequest\x1a\'.nibiru.dex.v1.QueryTotalSharesResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/nibiru/dex/pools/{poolId}/total_shares\x12\x83\x01\n\tSpotPrice\x12$.nibiru.dex.v1.QuerySpotPriceRequest\x1a%.nibiru.dex.v1.QuerySpotPriceResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/dex/pools/{poolId}/prices\x12\xb4\x01\n\x19\x45stimateSwapExactAmountIn\x12,.nibiru.dex.v1.QuerySwapExactAmountInRequest\x1a-.nibiru.dex.v1.QuerySwapExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/swap_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateSwapExactAmountOut\x12-.nibiru.dex.v1.QuerySwapExactAmountOutRequest\x1a..nibiru.dex.v1.QuerySwapExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/swap_exact_amount_out\x12\xb4\x01\n\x19\x45stimateJoinExactAmountIn\x12,.nibiru.dex.v1.QueryJoinExactAmountInRequest\x1a-.nibiru.dex.v1.QueryJoinExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/join_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateJoinExactAmountOut\x12-.nibiru.dex.v1.QueryJoinExactAmountOutRequest\x1a..nibiru.dex.v1.QueryJoinExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/join_exact_amount_out\x12\xb4\x01\n\x19\x45stimateExitExactAmountIn\x12,.nibiru.dex.v1.QueryExitExactAmountInRequest\x1a-.nibiru.dex.v1.QueryExitExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/exit_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateExitExactAmountOut\x12-.nibiru.dex.v1.QueryExitExactAmountOutRequest\x1a..nibiru.dex.v1.QueryExitExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/exit_exact_amount_outB+Z)github.com/NibiruChain/nibiru/x/dex/typesb\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYPOOLNUMBERREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolNumberRequest']
_QUERYPOOLNUMBERRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolNumberResponse']
_QUERYPOOLREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolRequest']
_QUERYPOOLRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolResponse']
_QUERYPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolsRequest']
_QUERYPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolsResponse']
_QUERYPOOLPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolParamsRequest']
_QUERYPOOLPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolParamsResponse']
_QUERYNUMPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryNumPoolsRequest']
_QUERYNUMPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryNumPoolsResponse']
_QUERYTOTALLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityRequest']
_QUERYTOTALLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityResponse']
_QUERYTOTALPOOLLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityRequest']
_QUERYTOTALPOOLLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityResponse']
_QUERYTOTALSHARESREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalSharesRequest']
_QUERYTOTALSHARESRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalSharesResponse']
_QUERYSPOTPRICEREQUEST = DESCRIPTOR.message_types_by_name['QuerySpotPriceRequest']
_QUERYSPOTPRICERESPONSE = DESCRIPTOR.message_types_by_name['QuerySpotPriceResponse']
_QUERYSWAPEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInRequest']
_QUERYSWAPEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInResponse']
_QUERYSWAPEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutRequest']
_QUERYSWAPEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutResponse']
_QUERYJOINEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInRequest']
_QUERYJOINEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInResponse']
_QUERYJOINEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutRequest']
_QUERYJOINEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutResponse']
_QUERYEXITEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInRequest']
_QUERYEXITEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInResponse']
_QUERYEXITEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutRequest']
_QUERYEXITEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryPoolNumberRequest = _reflection.GeneratedProtocolMessageType('QueryPoolNumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLNUMBERREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberRequest)
  })
_sym_db.RegisterMessage(QueryPoolNumberRequest)

QueryPoolNumberResponse = _reflection.GeneratedProtocolMessageType('QueryPoolNumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLNUMBERRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberResponse)
  })
_sym_db.RegisterMessage(QueryPoolNumberResponse)

QueryPoolRequest = _reflection.GeneratedProtocolMessageType('QueryPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolRequest)
  })
_sym_db.RegisterMessage(QueryPoolRequest)

QueryPoolResponse = _reflection.GeneratedProtocolMessageType('QueryPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolResponse)
  })
_sym_db.RegisterMessage(QueryPoolResponse)

QueryPoolsRequest = _reflection.GeneratedProtocolMessageType('QueryPoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsRequest)
  })
_sym_db.RegisterMessage(QueryPoolsRequest)

QueryPoolsResponse = _reflection.GeneratedProtocolMessageType('QueryPoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsResponse)
  })
_sym_db.RegisterMessage(QueryPoolsResponse)

QueryPoolParamsRequest = _reflection.GeneratedProtocolMessageType('QueryPoolParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLPARAMSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsRequest)
  })
_sym_db.RegisterMessage(QueryPoolParamsRequest)

QueryPoolParamsResponse = _reflection.GeneratedProtocolMessageType('QueryPoolParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLPARAMSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsResponse)
  })
_sym_db.RegisterMessage(QueryPoolParamsResponse)

QueryNumPoolsRequest = _reflection.GeneratedProtocolMessageType('QueryNumPoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYNUMPOOLSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsRequest)
  })
_sym_db.RegisterMessage(QueryNumPoolsRequest)

QueryNumPoolsResponse = _reflection.GeneratedProtocolMessageType('QueryNumPoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYNUMPOOLSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsResponse)
  })
_sym_db.RegisterMessage(QueryNumPoolsResponse)

QueryTotalLiquidityRequest = _reflection.GeneratedProtocolMessageType('QueryTotalLiquidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALLIQUIDITYREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityRequest)
  })
_sym_db.RegisterMessage(QueryTotalLiquidityRequest)

QueryTotalLiquidityResponse = _reflection.GeneratedProtocolMessageType('QueryTotalLiquidityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALLIQUIDITYRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityResponse)
  })
_sym_db.RegisterMessage(QueryTotalLiquidityResponse)

QueryTotalPoolLiquidityRequest = _reflection.GeneratedProtocolMessageType('QueryTotalPoolLiquidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALPOOLLIQUIDITYREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityRequest)
  })
_sym_db.RegisterMessage(QueryTotalPoolLiquidityRequest)

QueryTotalPoolLiquidityResponse = _reflection.GeneratedProtocolMessageType('QueryTotalPoolLiquidityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALPOOLLIQUIDITYRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityResponse)
  })
_sym_db.RegisterMessage(QueryTotalPoolLiquidityResponse)

QueryTotalSharesRequest = _reflection.GeneratedProtocolMessageType('QueryTotalSharesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALSHARESREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesRequest)
  })
_sym_db.RegisterMessage(QueryTotalSharesRequest)

QueryTotalSharesResponse = _reflection.GeneratedProtocolMessageType('QueryTotalSharesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALSHARESRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesResponse)
  })
_sym_db.RegisterMessage(QueryTotalSharesResponse)

QuerySpotPriceRequest = _reflection.GeneratedProtocolMessageType('QuerySpotPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTPRICEREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceRequest)
  })
_sym_db.RegisterMessage(QuerySpotPriceRequest)

QuerySpotPriceResponse = _reflection.GeneratedProtocolMessageType('QuerySpotPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTPRICERESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceResponse)
  })
_sym_db.RegisterMessage(QuerySpotPriceResponse)

QuerySwapExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInRequest)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountInRequest)

QuerySwapExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInResponse)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountInResponse)

QuerySwapExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountOutRequest)

QuerySwapExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountOutResponse)

QueryJoinExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInRequest)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountInRequest)

QueryJoinExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInResponse)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountInResponse)

QueryJoinExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountOutRequest)

QueryJoinExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountOutResponse)

QueryExitExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInRequest)
  })
_sym_db.RegisterMessage(QueryExitExactAmountInRequest)

QueryExitExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInResponse)
  })
_sym_db.RegisterMessage(QueryExitExactAmountInResponse)

QueryExitExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QueryExitExactAmountOutRequest)

QueryExitExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QueryExitExactAmountOutResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/NibiruChain/nibiru/x/dex/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALSHARESRESPONSE.fields_by_name['totalShares']._options = None
  _QUERYTOTALSHARESRESPONSE.fields_by_name['totalShares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['tokenIn']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['tokenIn']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['tokenOut']._options = None
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['tokenOut']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['tokenOut']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['tokenOut']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['tokenIn']._options = None
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['tokenIn']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name['tokensIn']._options = None
  _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name['tokensIn']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"tokens_in\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['poolSharesOut']._options = None
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['poolSharesOut']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"pool_shares_out\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['remCoins']._options = None
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['remCoins']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"rem_coins\"\310\336\037\000'
  _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name['poolSharesIn']._options = None
  _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name['poolSharesIn']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\025yaml:\"pool_shares_in\"\310\336\037\000'
  _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name['tokensOut']._options = None
  _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name['tokensOut']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\024\022\022/nibiru/dex/params'
  _QUERY.methods_by_name['PoolNumber']._options = None
  _QUERY.methods_by_name['PoolNumber']._serialized_options = b'\202\323\344\223\002\031\022\027/nibiru/dex/pool_number'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\022\022\020/nibiru/dex/pool'
  _QUERY.methods_by_name['Pools']._options = None
  _QUERY.methods_by_name['Pools']._serialized_options = b'\202\323\344\223\002\023\022\021/nibiru/dex/pools'
  _QUERY.methods_by_name['PoolParams']._options = None
  _QUERY.methods_by_name['PoolParams']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/dex/pools/{poolId}/params'
  _QUERY.methods_by_name['NumPools']._options = None
  _QUERY.methods_by_name['NumPools']._serialized_options = b'\202\323\344\223\002\027\022\025/nibiru/dex/num_pools'
  _QUERY.methods_by_name['TotalLiquidity']._options = None
  _QUERY.methods_by_name['TotalLiquidity']._serialized_options = b'\202\323\344\223\002\035\022\033/nibiru/dex/total_liquidity'
  _QUERY.methods_by_name['TotalPoolLiquidity']._options = None
  _QUERY.methods_by_name['TotalPoolLiquidity']._serialized_options = b'\202\323\344\223\0021\022//nibiru/dex/pools/{poolId}/total_pool_liquidity'
  _QUERY.methods_by_name['TotalShares']._options = None
  _QUERY.methods_by_name['TotalShares']._serialized_options = b'\202\323\344\223\002)\022\'/nibiru/dex/pools/{poolId}/total_shares'
  _QUERY.methods_by_name['SpotPrice']._options = None
  _QUERY.methods_by_name['SpotPrice']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/dex/pools/{poolId}/prices'
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/swap_exact_amount_in'
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/swap_exact_amount_out'
  _QUERY.methods_by_name['EstimateJoinExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateJoinExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/join_exact_amount_in'
  _QUERY.methods_by_name['EstimateJoinExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateJoinExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/join_exact_amount_out'
  _QUERY.methods_by_name['EstimateExitExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateExitExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/exit_exact_amount_in'
  _QUERY.methods_by_name['EstimateExitExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateExitExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/exit_exact_amount_out'
  _QUERYPARAMSREQUEST._serialized_start=205
  _QUERYPARAMSREQUEST._serialized_end=225
  _QUERYPARAMSRESPONSE._serialized_start=227
  _QUERYPARAMSRESPONSE._serialized_end=293
  _QUERYPOOLNUMBERREQUEST._serialized_start=295
  _QUERYPOOLNUMBERREQUEST._serialized_end=319
  _QUERYPOOLNUMBERRESPONSE._serialized_start=321
  _QUERYPOOLNUMBERRESPONSE._serialized_end=362
  _QUERYPOOLREQUEST._serialized_start=364
  _QUERYPOOLREQUEST._serialized_end=398
  _QUERYPOOLRESPONSE._serialized_start=400
  _QUERYPOOLRESPONSE._serialized_end=454
  _QUERYPOOLSREQUEST._serialized_start=456
  _QUERYPOOLSREQUEST._serialized_end=535
  _QUERYPOOLSRESPONSE._serialized_start=537
  _QUERYPOOLSRESPONSE._serialized_end=654
  _QUERYPOOLPARAMSREQUEST._serialized_start=656
  _QUERYPOOLPARAMSREQUEST._serialized_end=696
  _QUERYPOOLPARAMSRESPONSE._serialized_start=698
  _QUERYPOOLPARAMSRESPONSE._serialized_end=770
  _QUERYNUMPOOLSREQUEST._serialized_start=772
  _QUERYNUMPOOLSREQUEST._serialized_end=794
  _QUERYNUMPOOLSRESPONSE._serialized_start=796
  _QUERYNUMPOOLSRESPONSE._serialized_end=837
  _QUERYTOTALLIQUIDITYREQUEST._serialized_start=839
  _QUERYTOTALLIQUIDITYREQUEST._serialized_end=867
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_start=870
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_end=1015
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_start=1017
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_end=1065
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_start=1068
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_end=1217
  _QUERYTOTALSHARESREQUEST._serialized_start=1219
  _QUERYTOTALSHARESREQUEST._serialized_end=1260
  _QUERYTOTALSHARESRESPONSE._serialized_start=1262
  _QUERYTOTALSHARESRESPONSE._serialized_end=1365
  _QUERYSPOTPRICEREQUEST._serialized_start=1367
  _QUERYSPOTPRICEREQUEST._serialized_end=1451
  _QUERYSPOTPRICERESPONSE._serialized_start=1453
  _QUERYSPOTPRICERESPONSE._serialized_end=1496
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_start=1499
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_end=1638
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_start=1640
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_end=1743
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_start=1746
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_end=1887
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=1889
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=1991
  _QUERYJOINEXACTAMOUNTINREQUEST._serialized_start=1994
  _QUERYJOINEXACTAMOUNTINREQUEST._serialized_end=2156
  _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_start=2159
  _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_end=2403
  _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_start=2405
  _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_end=2453
  _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_start=2455
  _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_end=2488
  _QUERYEXITEXACTAMOUNTINREQUEST._serialized_start=2491
  _QUERYEXITEXACTAMOUNTINREQUEST._serialized_end=2633
  _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_start=2636
  _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_end=2785
  _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_start=2787
  _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_end=2835
  _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_start=2837
  _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_end=2870
  _QUERY._serialized_start=2873
  _QUERY._serialized_end=5284
# @@protoc_insertion_point(module_scope)
