"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions
import vpool.v1.vpool_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryReserveAssetsRequest(google.protobuf.message.Message):
    """---------------------------------------- QueryReserveAssets

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_FIELD_NUMBER: builtins.int
    pair: typing.Text
    """always BASE:QUOTE, e.g. BTC:NUSD or ETH:NUSD"""

    def __init__(self,
        *,
        pair: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair",b"pair"]) -> None: ...
global___QueryReserveAssetsRequest = QueryReserveAssetsRequest

class QueryReserveAssetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_RESERVE_FIELD_NUMBER: builtins.int
    base_asset_reserve: typing.Text
    """base asset is the crypto asset, e.g. BTC or ETH"""

    quote_asset_reserve: typing.Text
    """quote asset is usually stablecoin, in our case NUSD"""

    def __init__(self,
        *,
        base_asset_reserve: typing.Text = ...,
        quote_asset_reserve: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_reserve",b"base_asset_reserve","quote_asset_reserve",b"quote_asset_reserve"]) -> None: ...
global___QueryReserveAssetsResponse = QueryReserveAssetsResponse

class QueryAllPoolsRequest(google.protobuf.message.Message):
    """---------------------------------------- QueryAllPools

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryAllPoolsRequest = QueryAllPoolsRequest

class QueryAllPoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOLS_FIELD_NUMBER: builtins.int
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vpool.v1.vpool_pb2.Pool]: ...
    def __init__(self,
        *,
        pools: typing.Optional[typing.Iterable[vpool.v1.vpool_pb2.Pool]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pools",b"pools"]) -> None: ...
global___QueryAllPoolsResponse = QueryAllPoolsResponse

class QueryBaseAssetPriceRequest(google.protobuf.message.Message):
    """---------------------------------------- BaseAssetPrice

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    BASE_ASSET_AMOUNT_FIELD_NUMBER: builtins.int
    pair: typing.Text
    direction: vpool.v1.vpool_pb2.Direction.ValueType
    base_asset_amount: typing.Text
    """base asset is the crypto asset, e.g. BTC or ETH"""

    def __init__(self,
        *,
        pair: typing.Text = ...,
        direction: vpool.v1.vpool_pb2.Direction.ValueType = ...,
        base_asset_amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_amount",b"base_asset_amount","direction",b"direction","pair",b"pair"]) -> None: ...
global___QueryBaseAssetPriceRequest = QueryBaseAssetPriceRequest

class QueryBaseAssetPriceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRICE_IN_QUOTE_DENOM_FIELD_NUMBER: builtins.int
    price_in_quote_denom: typing.Text
    def __init__(self,
        *,
        price_in_quote_denom: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["price_in_quote_denom",b"price_in_quote_denom"]) -> None: ...
global___QueryBaseAssetPriceResponse = QueryBaseAssetPriceResponse
