"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import stablecoin.params_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the stablecoin module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    MODULE_ACCOUNT_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> stablecoin.params_pb2.Params: ...
    @property
    def module_account_balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        params: typing.Optional[stablecoin.params_pb2.Params] = ...,
        module_account_balance: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_account_balance",b"module_account_balance","params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_account_balance",b"module_account_balance","params",b"params"]) -> None: ...
global___GenesisState = GenesisState
