"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import lockup.v1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    LockedCoins: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLockedCoinsRequest,
        lockup.v1.query_pb2.QueryLockedCoinsResponse]

    Lock: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLockRequest,
        lockup.v1.query_pb2.QueryLockResponse]

    LocksByAddress: grpc.UnaryUnaryMultiCallable[
        lockup.v1.query_pb2.QueryLocksByAddress,
        lockup.v1.query_pb2.QueryLocksByAddressResponse]


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def LockedCoins(self,
        request: lockup.v1.query_pb2.QueryLockedCoinsRequest,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLockedCoinsResponse: ...

    @abc.abstractmethod
    def Lock(self,
        request: lockup.v1.query_pb2.QueryLockRequest,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLockResponse: ...

    @abc.abstractmethod
    def LocksByAddress(self,
        request: lockup.v1.query_pb2.QueryLocksByAddress,
        context: grpc.ServicerContext,
    ) -> lockup.v1.query_pb2.QueryLocksByAddressResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
