"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState contains a set of fee allowances, persisted from the store"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ALLOWANCES_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]: ...
    def __init__(self,
        *,
        allowances: typing.Optional[typing.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances",b"allowances"]) -> None: ...
global___GenesisState = GenesisState
