"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EventGrant(google.protobuf.message.Message):
    """EventGrant is emitted on Msg/Grant"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: typing.Text
    """Msg type URL for which an autorization is granted"""

    granter: typing.Text
    """Granter account address"""

    grantee: typing.Text
    """Grantee account address"""

    def __init__(self,
        *,
        msg_type_url: typing.Text = ...,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","granter",b"granter","msg_type_url",b"msg_type_url"]) -> None: ...
global___EventGrant = EventGrant

class EventRevoke(google.protobuf.message.Message):
    """EventRevoke is emitted on Msg/Revoke"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    msg_type_url: typing.Text
    """Msg type URL for which an autorization is revoked"""

    granter: typing.Text
    """Granter account address"""

    grantee: typing.Text
    """Grantee account address"""

    def __init__(self,
        *,
        msg_type_url: typing.Text = ...,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","granter",b"granter","msg_type_url",b"msg_type_url"]) -> None: ...
global___EventRevoke = EventRevoke
