"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgCreateVestingAccount(google.protobuf.message.Message):
    """MsgCreateVestingAccount defines a message that enables creating a vesting
    account.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FROM_ADDRESS_FIELD_NUMBER: builtins.int
    TO_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    DELAYED_FIELD_NUMBER: builtins.int
    from_address: typing.Text
    to_address: typing.Text
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    end_time: builtins.int
    delayed: builtins.bool
    def __init__(self,
        *,
        from_address: typing.Text = ...,
        to_address: typing.Text = ...,
        amount: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        end_time: builtins.int = ...,
        delayed: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount","delayed",b"delayed","end_time",b"end_time","from_address",b"from_address","to_address",b"to_address"]) -> None: ...
global___MsgCreateVestingAccount = MsgCreateVestingAccount

class MsgCreateVestingAccountResponse(google.protobuf.message.Message):
    """MsgCreateVestingAccountResponse defines the Msg/CreateVestingAccount response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgCreateVestingAccountResponse = MsgCreateVestingAccountResponse
