"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Params(google.protobuf.message.Message):
    """Params defines the parameters for the module."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STARTINGPOOLNUMBER_FIELD_NUMBER: builtins.int
    POOL_CREATION_FEE_FIELD_NUMBER: builtins.int
    WHITELISTED_ASSET_FIELD_NUMBER: builtins.int
    startingPoolNumber: builtins.int
    """The start pool number, i.e. the first pool number that isn't taken yet."""

    @property
    def pool_creation_fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """The cost of creating a pool, taken from the pool creator's account."""
        pass
    @property
    def whitelisted_asset(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """The assets that can be used to create liquidity pools"""
        pass
    def __init__(self,
        *,
        startingPoolNumber: builtins.int = ...,
        pool_creation_fee: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        whitelisted_asset: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_creation_fee",b"pool_creation_fee","startingPoolNumber",b"startingPoolNumber","whitelisted_asset",b"whitelisted_asset"]) -> None: ...
global___Params = Params
