"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import epochs.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    EpochInfos: grpc.UnaryUnaryMultiCallable[
        epochs.query_pb2.QueryEpochsInfoRequest,
        epochs.query_pb2.QueryEpochsInfoResponse]
    """EpochInfos provide running epochInfos"""

    CurrentEpoch: grpc.UnaryUnaryMultiCallable[
        epochs.query_pb2.QueryCurrentEpochRequest,
        epochs.query_pb2.QueryCurrentEpochResponse]
    """CurrentEpoch provide current epoch of specified identifier"""


class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""
    @abc.abstractmethod
    def EpochInfos(self,
        request: epochs.query_pb2.QueryEpochsInfoRequest,
        context: grpc.ServicerContext,
    ) -> epochs.query_pb2.QueryEpochsInfoResponse:
        """EpochInfos provide running epochInfos"""
        pass

    @abc.abstractmethod
    def CurrentEpoch(self,
        request: epochs.query_pb2.QueryCurrentEpochRequest,
        context: grpc.ServicerContext,
    ) -> epochs.query_pb2.QueryCurrentEpochResponse:
        """CurrentEpoch provide current epoch of specified identifier"""
        pass


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
